import org.omg.appinst.*;

public class Example {

	public static void main(String[] args) {
		// The InstrumentationServiceFactory instance
		// will be provided by implementations
		Infrastructure infrastructure = impl.Infrastructure.getInstance();

		ObservableObject obj = initializeInstrumentation(infrastructure);

		for (int i = 0; i < 10; i++) {
			int instrumentedVar = (int) (Math.random() * 100.0);

			if (obj != null) {
				try {
					obj.setValue(0, i);
					obj.setValue(1, instrumentedVar);
					obj.saveObservation();
				} catch (ReturnCodeException e) {

				}
			}
		}

		infrastructure.finalizeInstrumentation();
	}

	public static ObservableObject initializeInstrumentation(
			Infrastructure infrastructure) {

		try {
			InstrumentationService service = infrastructure
					.createService("ExampleInstrumentedApplication");
			ObservableSchema schema = service
					.createObservableSchema("MySchema");
			// Implementation will provide classes implementing
			// the properties interfaces
			FieldProperties fieldProps = new impl.FieldProperties();
			fieldProps.setType(DataValueKind.TYPE_INT32);
			schema.createField("i", fieldProps);
			schema.createField("instrumented_var", fieldProps);

			ObservableScope scope = service
					.createObservableScope("DefaultScope");

			ObservableObjectProperties objProperties = new impl.ObservableObjectProperties();
			objProperties.setObservableSchemaName(schema.getName());

			ObservableObject obj = scope.createObservableObject("MyObject",
					objProperties);

			scope.enableDataCollection();

			return obj;

		} catch (ReturnCodeException ex) {
			infrastructure.finalizeInstrumentation();
			return null;
		}
	}

}
